.. |logo| image:: https://beeware.org/project/projects/tools/briefcase/briefcase.png
   :width: 72px
   :target: https://beeware.org/briefcase

.. |pyversions| image:: https://img.shields.io/pypi/pyversions/briefcase.svg
   :target: https://pypi.python.org/pypi/briefcase
   :alt: Python Versions

.. |version| image:: https://img.shields.io/pypi/v/briefcase.svg
   :target: https://pypi.python.org/pypi/briefcase
   :alt: PyPI Version

.. |maturity| image:: https://img.shields.io/pypi/status/briefcase.svg
   :target: https://pypi.python.org/pypi/briefcase
   :alt: Maturity

.. |license| image:: https://img.shields.io/pypi/l/briefcase.svg
   :target: https://github.com/beeware/briefcase/blob/main/LICENSE
   :alt: BSD License

.. |ci| image:: https://github.com/beeware/briefcase/workflows/CI/badge.svg?branch=main
   :target: https://github.com/beeware/briefcase/actions
   :alt: Build Status

.. |social| image:: https://img.shields.io/discord/836455665257021440?label=Discord%20Chat&logo=discord&style=plastic
   :target: https://beeware.org/bee/chat/
   :alt: Discord server

|logo|

Briefcase
=========

|pyversions| |version| |maturity| |license| |ci| |social|

Briefcase is a tool for converting a Python project into a standalone native
application. You can package projects for:

* Mac
* Windows
* Linux
* iPhone/iPad
* Android
* Web

Support for AppleTV, watchOS, and wearOS deployments is planned.

Getting started
---------------

To install Briefcase, run::

   $ python -m pip install briefcase

If you would like a full introduction to using Briefcase, try the `BeeWare tutorial
<https://docs.beeware.org>`__. This tutorial walks you through the process of creating
and packaging a new application with Briefcase.

Documentation
-------------

Documentation for Briefcase can be found on `Read The Docs`_.

Community
---------

Briefcase is part of the `BeeWare suite`_. You can talk to the community through:

* `@beeware@fosstodon.org on Mastodon <https://fosstodon.org/@beeware>`__

* `Discord <https://beeware.org/bee/chat/>`__

* The Briefcase `Github Discussions forum <https://github.com/beeware/briefcase/discussions>`__

We foster a welcoming and respectful community as described in our
`BeeWare Community Code of Conduct`_.

Contributing
------------

If you experience problems with Briefcase, `log them on GitHub`_. If you
want to contribute code, please `fork the code`_ and `submit a pull request`_.

.. _BeeWare suite: https://beeware.org
.. _Read The Docs: https://briefcase.readthedocs.io
.. _BeeWare Community Code of Conduct: https://beeware.org/community/behavior/
.. _log them on Github: https://github.com/beeware/briefcase/issues
.. _fork the code: https://github.com/beeware/briefcase
.. _submit a pull request: https://github.com/beeware/briefcase/pulls
